/**
 * @author v_wangyan
 * @date 2012-11-05
 */ 
var skin = window.skin || {};
/**
 * 获取元素对象
 * @param  {string} element 元素id
 * @return {object}         返回元素对象
 */
skin.g = function(element) {
    return document.getElementById(element) || element;
},
/**
 * 转换JSON对象
 * @param  {string} jsonString json字符串
 * @return {object}            json对象
 */
skin.jsonDecode =function(jsonString) {
	return (new Function("return " + jsonString))();
},
/**
 * 生成指定范围内的随机数
 * @param  {number} min 最小值
 * @param  {number} max 最大值
 * @return {number}     返回随机值
 */
skin.randomInt = function (min, max) {
    return Math.floor(Math.random() * (max - min + 1) + min);
}
/**
 * 显示dom
 * @param  {string} id dom的id
 * @return {void}    无
 */
skin.show = function(id) {
	skin.isShow(id, true);
},
/**
 * 隐藏dom
 * @param  {string} id dom的id
 * @return {void}    无
 */
skin.hide = function(id) {
    skin.isShow(id, false);
},
/**
 * 是否显示
 * @return {bool} 返回布尔值
 */
skin.isShow = function() {
    skin.g(id).style.display = flag ? 'block' : 'none';
},
/**
 * 添加样式
 * @param {string|object} element   目标元素
 * @param {string} className 样式名称
 */
skin.addClass = function(element, className) { 
	element = skin.g(element)||element;
    var classArray = className.split(/\s+/),
        result = element.className,
        classMatch = " " + result + " ",
        i = 0,
        l = classArray.length;

    for (; i < l; i++) {
         if ( classMatch.indexOf( " " + classArray[i] + " " ) < 0 ) {
             result += (result ? ' ' : '') + classArray[i];
         }
    }

    element.className = result;
},
/**
 * 移除样式
 * @param  {string|object} element   目标元素
 * @param  {string} className 样式名称
 * @return {void}           无
 */
skin.removeClass = function(element, className) { 
	element = skin.g(element)||element; 

    var oldClasses = element.className.split(/\s+/),
        newClasses = className.split(/\s+/),
        lenOld,
        lenDel = newClasses.length,
        j,
        i = 0;  
    for (; i < lenDel; ++i) {
        for(j = 0, lenOld = oldClasses.length; j < lenOld; ++j) {
            if (oldClasses[j] == newClasses[i]) {
            	oldClasses.splice(j, 1);
            	break;
            }
        }
    }
    element.className = oldClasses.join(' ');
},
/**
 * 设置字体
 * @param {int}   
 * @return void
 */
skin.setFontFamily = function (key) {   //设置字体:  0-宋体 ; 1-微软雅黑;
    key = key || '0';
    var obj = document.body;
    var font = '';
    if (key) {
        font = '"微软雅黑", "宋体", Arial, Verdana';
    } else {
        font = '"宋体", "微软雅黑", Arial, Verdana';
    }
    obj.style.fontFamily = font;
}
/**
 * 设置页面显示的字体(win7--雅黑字,其他为宋体)
 * @param 无
 * @return string
 */
skin.getSysver = function () {
    var key = 0;
    try {
        key = execOrder('sysver');
        if ('6.1' == key) {
            key = 1;
        }
    } catch (e) {   }   
    
    skin.setFontFamily(key); 
}
/**
 * 处理icon点击
 * @param  {event} e          事件
 * @param  {bool} rightClick 是否为右键(点击)
 * @param  {number} key        iconid
 * @return {void}            无
 */
skin.execMouseDown = function (e, rightClick, key) {
    //取消冒泡事件
    e.stopPropagation(); 
    
    var order = rightClick ? 'mouseRDown' : 'mouseLDown';
    try {
        window.external.SyncRequest(order, key);
    } catch (e) {}  
},
/**
 * 处理右键点击
 * @param  {string} id elementid
 * @return {void}    无
 */
skin.rightButton = function (id) {
    if (event.button == 2) {
       skin.execMouseDown(event, true, id);
    }
},
/**
 * 执行命令
 * @param {string} 命令名称
 * @param {string} 值
 * @return string | void
 */
skin.execOrder = function (order, key) {
    var info = '';
    try { 
        key = (key.length == 0 ? '0' : key); 
        info = window.external.SyncRequest(order, key);
    } catch (e) {       
    } 
    return info;
},
/**
 * 执行客户端命令,获取参数
 * @param  {string} order 命令名称
 * @param  {string} param 参数
 * @return {void|object}       无|-
 */
skin.execSync = function (order, param) {
    try {
        if (window.external.SyncRequest) {
            return window.external.SyncRequest(order, param);
        } 
    } catch (e) {
        return '';
    }
    return '';
},
/**
 * 设置本地存储--(使用)获取到对应参数值,进行赋值后重新存储该值
 * @type {Object}
 */
skin.storage = {
    set: function (key, value) {
        this.data(key, value);
    },
    get: function (key) {  
        return this.data(key);
    },
    /**
     * 处理存储数据
     * @param  {string} key   存储(获取的)key
     * @param  {[type]} value 存储的值
     * @return {boolea | object}       操作结果
     */
    data: function (key, value) { 
        var configData = skin.execSync('readConfig') || '{}'; 
        if (typeof configData  == 'string') {
            configData = JSON.parse(configData);
        }         
        if (value) {     
            configData[key] = value;
            skin.execSync('saveConfig', JSON.stringify(configData));            
            return true;
        } else {                                 
            return (key ? (configData[key] || false) : configData);
        }
        return false;
    }
},
//获取RD数据status,null 时返回当前状态
/**
 * 设置icon状态
 * @param  {string} id  icon的id
 * @param  {string} key 命令
 * @return {void}     无
 */
skin.getExecStatus = function (id, key) {  
    if (typeof skin.g(id) == 'string') {
        return;
    }
    var statu = skin.execSync('getButtonState', key) || skin.g(id).getAttribute('statu'); 
    return statu;
},
/**
 * 初始输入法状态  
 * 参数:0 (中英文切换) 返回值: 0 英文 1 中文;
 * 参数:1 (全半角切换) 返回值: 0 半角 1 全角; 
 * 参数:2 (中英文标点) 返回值: 0 英文标点 1 中文标点;
 * 参数:3 (软键盘)
 * 参数:4 (登录)            返回值: 0 未登录 1 已登录
 * 参数:5 (配置)
 */
skin.setIMEStatus = function () { 
    setButtonState('0', skin.getExecStatus('language', '0'));    
    setButtonState('1', skin.getExecStatus('characters', '1'));  
    setButtonState('2', skin.getExecStatus('punctuation', '2')); 
    setButtonState('4', skin.getExecStatus('login', '4'));   
},
/**
 * 绑定输入法icon点击/hover等事件
 * @return {void} 无
 */
skin.bindEvent = function () {
    var icons = skin.g('iconEvent').getElementsByTagName('img');
    for (var i = 0, len = icons.length; i < len; i++) {        
        icons[i].onclick = function () { 
            skin.execMouseDown(event, false, this.getAttribute('key'));
        }
        icons[i].onmouseup = function () { 
            skin.rightButton(this.getAttribute('key'));
        }
        icons[i].onmouseover = function () { 
            skin.execOrder('mouseOver', this.getAttribute('key'));
        }
        icons[i].onmouseout = function () { 
            skin.execOrder('mouseOver', 'null');
        }
    }
    document.onclick  =function () {
        skin.execMouseDown(event, false, 'null');    
    }
    
    document.onmouseup =function () {  
        skin.rightButton('null'); 
    }
},
/**
 * 更新记录时间
 * @return {void} 无
 */
skin.changeCouplets = function () { 
    skin.changeStatu = 0;
    skin.countTimer = 1000 * 60 * 30;
    skin.isChangeImg = false;
    var date = null
        dateVal = 0; 
    if (skin.changeInterval) {
        clearInterval(skin.changeInterval);
    }
    skin.changeInterval = window.setInterval(function () {  
        date = new Date();           
        try {
            dateVal = date.getDate();    
            if (dateVal != skin.date) {    
                skin.date = dateVal;
                skin.changeStatu = 1; 
                proccessChangeCoutlets();

                if (date.getMonth() == 1 && date.getFullYear() == 2013) {
                    proccessChangeImg();
                }   
            } else if (dateVal == skin.date && skin.changeStatu == 1) { 
                skin.changeStatu = 0;
            }
        } catch (e) {
            Log('111未知异常');
        }        
    }, skin.countTimer);
},
skin.initSKin = function () { 
    var _date = new Date();
    skin.date = _date.getDate();

    // 初始场景图片
    if (_date.getFullYear() == 2013) {
        proccessChangeImg();
    }    

    // 显示对联
    proccessChangeCoutlets();

    // 定时检索 
    skin.changeCouplets();

    skin.maxHeight = 141;
    skin.minHeight = 0;
    skin.slideInterval = null;
    skin.g('box').style.height = skin.minHeight;

    skin.g('main').onmouseover = function () {
        slider(true);
    }
    skin.g('main').onmouseout = function () {
        slider(false);
    }
    skin.g('box').onmouseover = function () {
        slider(true);
    }
    skin.g('box').onmouseout = function () {
        slider(false);
    }
}
function slider(isUp) {
    stop();
    var height = parseInt(skin.g('box').style.height);
    var step = 1;
    skin.slideInterval = window.setInterval(function () {
        if (isUp) {
            height += step;
            if (height > skin.maxHeight) {
                stop();
                return;
            }
        } else {
            height -= step;
            if (height < skin.minHeight) {
                stop();
                return;
            }
        }
        skin.g('box').style.height = height + 'px';
    }, 1);
}
function stop() {
    window.clearInterval(skin.slideInterval);
}
function proccessChangeCoutlets() {
    var newCouplets = getChangeCoutlets(); 
    skin.g('leftCouplets').innerHTML = newCouplets.left;
    skin.g('rightCouplets').innerHTML = newCouplets.right;
}

function proccessChangeImg() {
    var changeInfo = getChangeImg(),
        clsName = 'dateimg pos-abs ',
        imgSrc = ''; 
    if (changeInfo) { 
        clsName += changeInfo.clsName; 
        imgSrc = 'url(../images/' + changeInfo.imgName + ')';
    } else { 
        imgSrc = '';
    } 
    skin.g('dateImg').className = clsName;
    skin.g('dateImg').style.backgroundImage = imgSrc; 
}
/**
 * 获取新场景图片
 * @return {[type]} [description]
 */
function getChangeImg() {
    var date = new Date();
    skin.month = date.getMonth() + 1;
    skin.day = date.getDate();
    if (skin.month == 2 && config.dateImg[skin.day]) {
        if (skin.day >= 9) { 
            skin.g('main').className = 'main pos-abs newyear';
        } else {
            skin.g('main').className = 'main pos-abs';
        }
        return config.dateImg[skin.day];
    } else {
        skin.g('main').className = 'main pos-abs';
        return '';
    }
    return '';
}
/**
 * 获取新对联
 * @return {void} 无
 */
function getChangeCoutlets() {  
    var c = '', num = 0;
    var historyCouplets = skin.storage.get('couplets'); 
    if (!historyCouplets) { 
        historyCouplets = {};
    }
    skin.coupletsSize = config.couplets.length;
    skin.arrIndex = [];    
    for (var i= 0; i < skin.coupletsSize; i++) {        
        if (!historyCouplets['index_' + i]) {
            skin.arrIndex.push(i);
        }        
    } 
    
    if (skin.arrIndex.length > 0) {
        num = skin.randomInt(0, skin.arrIndex.length - 1);
        num = skin.arrIndex[num];  
    } else { 
        num = skin.randomInt(0, skin.coupletsSize - 1);
        historyCouplets = {};
    }
    
    historyCouplets["index_" + num] = "1"; 
    skin.storage.set('couplets', historyCouplets);

    // 新对联
    return config.couplets[num];  
}
/**
 * 在一支笔中打印日志
 * @param {string} str 打印的内容
 */
function Log(str) {   
    try {
        if(window.external.SyncRequest) { 
            window.external.SyncRequest('log', str);
        } else {   //在浏览器控制台中输出        
            console.log(str);
        }
    } catch (e) {}
}

// 供客户端调用
function setButtonState(key, statu) { 
    var status = config.buttonstatus;
    var id = '';
    key = key || '0';
    id = status[key].id;
    if (typeof skin.g(id) == 'string') {
        return;
    }
    statu =  statu || (skin.g(id).getAttribute('statu') == '0' ? '1' : '0');     
    skin.g(id).src = 'images/icons/' + status[key][statu];
    skin.g(id).setAttribute ('statu', statu);        
}


